<?php

if (!defined('ABSPATH')) exit; /* Exit if accessed directly */

class wp_lean_analytics_free
{

    //Plugin generics
    public function __construct($pp_plugin_name, $pp_plugin_name_read, $pp_plugin_name_read_short, $pp_plugin_filefolder_name = false)
    {
        //Set vars
        $this->pp_plugin_name = $pp_plugin_name;

        if ($pp_plugin_filefolder_name == false) {
            //Same as normal name
            $this->pp_plugin_filefolder_name = $pp_plugin_name;
        } else {
            //Different name
            $this->pp_plugin_filefolder_name = $pp_plugin_filefolder_name;
        }

        $this->pp_prefix = $pp_plugin_name . '_';
        $this->pp_plugin_name_read = $pp_plugin_name_read;
        $this->pp_plugin_name_read_short = $pp_plugin_name_read_short;

        //Specific configuration (Google)
        $this->pp_config['google_analytics_key'] = '';
        $this->pp_config['google_analytics_anonymize_ip'] = 'Y';
        $this->pp_config['google_analytics_track_frontend'] = 'Y';
        $this->pp_config['google_analytics_track_login_registration'] = 'N';
        $this->pp_config['google_analytics_track_admin_panel'] = 'N';
        $this->pp_config['google_analytics_track_loggedin'] = 'Y';
        $this->pp_config['google_analytics_respect_wp_consent_manager_pro_settings'] = 'Y';

        //Specific configuration (Facebook)
        $this->pp_config['facebook_analytics_key'] = '';
        $this->pp_config['facebook_analytics_track_frontend'] = 'Y';
        $this->pp_config['facebook_analytics_track_login_registration'] = 'N';
        $this->pp_config['facebook_analytics_track_admin_panel'] = 'N';
        $this->pp_config['facebook_analytics_track_loggedin'] = 'Y';
        $this->pp_config['facebook_analytics_respect_wp_consent_manager_pro_settings'] = 'Y';

        //Specific configuration (Smartlook)
        $this->pp_config['smartlook_analytics_key'] = '';
        $this->pp_config['smartlook_analytics_track_frontend'] = 'Y';
        $this->pp_config['smartlook_analytics_track_login_registration'] = 'N';
        $this->pp_config['smartlook_analytics_track_admin_panel'] = 'N';
        $this->pp_config['smartlook_analytics_track_loggedin'] = 'Y';
        $this->pp_config['smartlook_analytics_respect_wp_consent_manager_pro_settings'] = 'Y';

        //Constants
        $this->pp_constant['base_url_gopro'] = 'https://www.wpconsentmanager.com/plugins/wp-lean-analytics';
        $this->pp_constant['base_url_support'] = 'https://www.wpconsentmanager.com/support';

        $this->pp_config_attributes = false;
    }

    //Generic stuff
    public function activate()
    {
        /* Description: Performs activation */
        $plugin_data = $this->getPluginData($this->pp_plugin_filefolder_name);

        //Add generic options
        add_option($this->pp_prefix . 'version', $plugin_data['Version']);
        add_option($this->pp_prefix . 'db_version', $plugin_data['Version']);

        //Always update these options
        update_option($this->pp_prefix . 'db_version', $plugin_data['Version']);

        $administrator = get_role('administrator');
        $administrator->add_cap($this->pp_prefix . 'use');
        $administrator->add_cap($this->pp_prefix . 'function_wizard_use');
        $administrator->add_cap($this->pp_prefix . 'function_configuration_use');
        //$administrator->add_cap($this->pp_prefix . 'function_addons_use');
        //$administrator->add_cap($this->pp_prefix . 'function_tutorials_use');
        $administrator->add_cap($this->pp_prefix . 'function_support_use');
        $administrator->add_cap($this->pp_prefix . 'function_compatibility_use');
        $administrator->add_cap($this->pp_prefix . 'function_gopro_use');

    }

    public function deactivate()
    {
        /* Description: Performs deactivation */
        $administrator = get_role('administrator');
        $administrator->remove_cap($this->pp_prefix . 'use');
        $administrator->remove_cap($this->pp_prefix . 'function_wizard_use');
        $administrator->remove_cap($this->pp_prefix . 'function_configuration_use');
        $administrator->remove_cap($this->pp_prefix . 'function_addons_use');
        $administrator->remove_cap($this->pp_prefix . 'function_tutorials_use');
        $administrator->remove_cap($this->pp_prefix . 'function_support_use');
        $administrator->remove_cap($this->pp_prefix . 'function_compatibility_use');
        $administrator->remove_cap($this->pp_prefix . 'function_gopro_use');
    }

    public static function static_uninstall()
    {
        /* Description: Wrapper for uninstalling the plugin, as WordPress only accepts uninstall.php or static methods... */
        $GLOBALS[strtoupper(get_called_class()) . '_OBJECT']->uninstall();
    }

    public function uninstall()
    {
        /* Description: Performs uninstallation */
        //Delete options
        delete_option($this->pp_prefix . 'version');
        delete_option($this->pp_prefix . 'db_version');

        //Delete default options
        foreach ($this->pp_config AS $key => $value) {
            $this->pp_config[$key] = delete_option($this->pp_prefix . $key);
        }

        //Delete tables
        //$wpdb->query("DROP TABLE IF EXISTS ".$wpdb->prefix.$this->pp_prefix."xyz");
    }

    public function addHooks()
    {
        /* Description: Adds the hooks */

        //Add CSS where needed
        add_action('admin_enqueue_scripts', array($this, 'registerEnqueueAdminCSS'));

        //Add pages
        add_action('admin_menu', array($this, 'registerPages'), 9999);

        //Add post hooks
        add_action('admin_post_' . $this->pp_prefix . 'updateOptions', array($this, 'do_updateOptions'));

        //Add Google Analytics hooks
        if ((($this->pp_config['google_analytics_track_loggedin'] == 'Y')
                AND (get_current_user_id() > 0))
            OR (get_current_user_id() == 0)) {
            if ($this->pp_config['google_analytics_track_frontend'] == 'Y') {
                add_action('wp_footer', array($this, 'echoGoogleAnalyticsTracking'));
            }
            if ($this->pp_config['google_analytics_track_admin_panel'] == 'Y') {
                add_action('admin_head', array($this, 'echoGoogleAnalyticsTracking'));
            }
            if ($this->pp_config['google_analytics_track_login_registration'] == 'Y') {
                add_action('login_head', array($this, 'echoGoogleAnalyticsTracking'));
            }
        }

        //Add Facebook tracking pixel hooks
        if ((($this->pp_config['facebook_analytics_track_loggedin'] == 'Y')
                AND (get_current_user_id() > 0))
            OR (get_current_user_id() == 0)) {
            if ($this->pp_config['facebook_analytics_track_frontend'] == 'Y') {
                add_action('wp_footer', array($this, 'echoFacebookPixelTracking'));
            }
            if ($this->pp_config['facebook_analytics_track_admin_panel'] == 'Y') {
                add_action('admin_head', array($this, 'echoFacebookPixelTracking'));
            }
            if ($this->pp_config['facebook_analytics_track_login_registration'] == 'Y') {
                add_action('login_head', array($this, 'echoFacebookPixelTracking'));
            }
        }

        //Add Smartlook recorder hooks
        if ((($this->pp_config['smartlook_analytics_track_loggedin'] == 'Y')
                AND (get_current_user_id() > 0))
            OR (get_current_user_id() == 0)) {
            if ($this->pp_config['smartlook_analytics_track_frontend'] == 'Y') {
                add_action('wp_footer', array($this, 'echoSmartlookTracking'));
            }
            if ($this->pp_config['smartlook_analytics_track_admin_panel'] == 'Y') {
                add_action('admin_head', array($this, 'echoSmartlookTracking'));
            }
            if ($this->pp_config['smartlook_analytics_track_login_registration'] == 'Y') {
                add_action('login_head', array($this, 'echoSmartlookTracking'));
            }
        }
    }

    public function init()
    {
        /* Description: This initiates the plugin and is run everytime as long as the plugin is active. */

        //Load config definition
        $object = $this;
        require(plugin_dir_path(__FILE__) . "configuration.inc.php");

        //Add default options (cannot be performed in $this->activate, because "$this->pp_config" is not available there)
        foreach ($this->pp_config AS $key => $value) {
            if (get_option($this->pp_prefix . $key) == false) {
                //Option does not exist, add it
                add_option($this->pp_prefix . $key, $value);
            }
        }

        //Get config-Vars from database
        foreach ($this->pp_config AS $key => $value) {
            $this->pp_config[$key] = get_option($this->pp_prefix . $key);
        }

        //Add hooks
        $this->addHooks();
    }

    //Lib functions
    public function registerEnqueueAdminCSS()
    {
        /* Description: Enqueues plugin specific CSS in the admin panel */

        //No versioning needed, as only one instance of this can be present at the same time
        wp_register_style($this->pp_prefix . 'admin_css',
            plugins_url() . '/' . $this->pp_plugin_filefolder_name . '/plugin/css/admin.css');

        //Enqueue the script
        wp_enqueue_style($this->pp_prefix . 'admin_css');

        //Enqeue generic scripts
        wp_enqueue_style('thickbox');
        wp_enqueue_style('wp-pointer');
    }

    public function getPluginData($plugin_name = false)
    {
        /* Description: Generic function to retrieve the plugin data from the main plugin file. */
        if (!function_exists('get_plugin_data')) {
            //Without this, get_plugin_data only works in admin area
            require_once(ABSPATH . '/wp-admin/includes/plugin.php');
        }

        if ($plugin_name == false) {
            return false;
        } else {
            return get_plugin_data(WP_PLUGIN_DIR . '/' . $plugin_name . '/' . $plugin_name . '.php',
                $markup = false,
                $translate = false);
        }
    }

    public function getNextFreeMenuPosition($startposition)
    {
        /* Description: Get the next free menu position in Wordpress

           Thank you for the idea: http://blog.happyplugins.com/coding-how-to-avoid-conflict-menu-position-in-wordpress/
              - Important: Call add_menu hook as late as possible, so other plugins
                           that do not support this feature won't overwrite our nav entry
                           add_action('admin_menu', 'my_add_function', 9999);

        */
        $startposition = strval($startposition);

        foreach ($GLOBALS['menu'] as $key => $menu) {
            $positions[] = $key;
        }

        if (!in_array($startposition, $positions)) {
            //Position is free => return desired position
            return $startposition;
        } else {
            /* Position is taken ($key contains the position) => increment until next free position */
            while (in_array($startposition, $positions)) {
                $startposition += 0.00001;
                //
                $startposition = strval($startposition);
            }
            return $startposition;
        }
    }

    public function addAttribute($att_name, $name_read, $description, $mysql_type = 'varchar(50)', $default = NULL, $mandatory = false, $validator = false, $autosuggest = false, $openapi = true)
    {
        /* Description: Adds a configuration attribute exactly the same way as in PRO plugins (for compatibility reasons) */

        $this->pp_config_attributes[$att_name]['name'] = $att_name;
        $this->pp_config_attributes[$att_name]['name_read'] = $name_read;
        $this->pp_config_attributes[$att_name]['description'] = $description;
        $this->pp_config_attributes[$att_name]['mysql_type'] = $mysql_type;
        $this->pp_config_attributes[$att_name]['default'] = $default;
        $this->pp_config_attributes[$att_name]['mandatory'] = $mandatory;
        $this->pp_config_attributes[$att_name]['validator'] = $validator;
    }

    public function validateConfigAttribute($att_name, $old_value, $new_value)
    {
        /* Description: This validates whether a value can be set to a config attribute and returns status */

        if (isset($this->pp_config_attributes[$att_name])
            AND (is_array($this->pp_config_attributes[$att_name]))) {
            //Attribute exists

            //Remove slashes for comparison
            $new_value = stripslashes($new_value);

            if (($this->pp_config_attributes[$att_name]['mandatory'] == true)
                AND (!isset($new_value)
                    OR (strlen($new_value) < 1))) {
                //If mandatory attribute not set
                return 'ERROR_MANDATORY';
            } else {
                //Either not mandatory, or set

                if ($old_value == $new_value) {
                    //If not changed
                    return 'SAME';
                } elseif (($this->pp_config_attributes[$att_name]['mandatory'] == false)
                    AND isset($new_value)
                    AND (strlen($new_value) == 0)) {
                    //If not mandatory and string length is 0

                    //tbd: Maybe add NULL?
                    return 'CHANGEABLE';
                } else {
                    //If changed, check if it can be updated
                    if (isset($this->pp_config_attributes[$att_name]['validator'])
                        AND ($this->pp_config_attributes[$att_name]['validator'] != false)) {
                        //Attribute-validator available

                        if (is_callable($this->pp_config_attributes[$att_name]['validator'])) {
                            //Attribute-validator is a function => call it and return the status
                            return $this->pp_config_attributes[$att_name]['validator']($att_name, $old_value, $new_value, $this);
                        }

                        if (is_string($this->pp_config_attributes[$att_name]['validator'])) {
                            //Attribute-validator is a string => check regexp
                            if (preg_match($this->pp_config_attributes[$att_name]['validator'], $new_value)) {
                                return 'CHANGEABLE';
                            } else {
                                return 'ERROR_SYNTAX';
                            }
                        }

                        if (is_array($this->pp_config_attributes[$att_name]['validator'])) {
                            //Attribute-validator is an array => check if value in array
                            if (array_key_exists($new_value, $this->pp_config_attributes[$att_name]['validator'])) {
                                return 'CHANGEABLE';
                            } else {
                                return 'ERROR_ENUM';
                            }
                        }

                    } else {
                        //If false, then not allowed to change
                        return 'ERROR_NOT_ALLOWED';
                    }
                }
            }
        } else {
            //There is no such attribute in this object
            return 'ERROR_NO_ATTRIBUTE';
        }
    }

    public function updateConfigAttributes($old_array, $new_array)
    {
        /* Description: This updates several attributes at once, based on the NEW array */
        $return_array = array();

        if (isset($new_array)
            AND is_array($new_array)
            AND (count($new_array) > 0)) {
            foreach ($new_array AS $this_attribute => $this_value) {
                $return_array[$this_attribute] = $this->validateConfigAttribute($this_attribute, $old_array[$this_attribute], $this_value);

                if ($return_array[$this_attribute] == 'CHANGEABLE') {
                    //Only then update it
                    update_option($this->pp_prefix . $this_attribute, $this_value);
                    $this->pp_config[$this_attribute] = $this_value;
                }
            }
        }

        return $return_array;
    }

    //Plugin pages
    public function registerPages()
    {
        //Main page
        add_menu_page($this->pp_plugin_name_read_short, $this->pp_plugin_name_read_short, $this->pp_prefix . 'use', $this->pp_prefix . 'menuPages', array($this, 'pageDashboard'), 'dashicons-admin-plugins', $this->getNextFreeMenuPosition('65'));

        //Invisible pages
        //Configuration
        add_submenu_page(null, 'Configuration', 'Configuration', $this->pp_prefix . 'function_configuration_use', $this->pp_prefix . 'menuPageConfiguration', array($this, 'pageConfiguration'));

        //Visible pages
        //Wizard
        add_submenu_page($this->pp_prefix.'menuPages', 'Google Analytics Wizard', 'Google Analytics Wizard', $this->pp_prefix . 'function_wizard_use', $this->pp_prefix . 'menuPageGoogleAnalyticsWizard', array($this, 'pageGoogleAnalyticsWizard'));
        add_submenu_page($this->pp_prefix.'menuPages', 'Facebook Pixel Wizard', 'Facebook Pixel Wizard', $this->pp_prefix . 'function_wizard_use', $this->pp_prefix . 'menuPageFacebookPixelWizard', array($this, 'pageFacebookPixelWizard'));
        add_submenu_page($this->pp_prefix.'menuPages', 'Smartlook recording Wizard', 'Smartlook recording Wizard', $this->pp_prefix . 'function_wizard_use', $this->pp_prefix . 'menuPageSmartlookWizard', array($this, 'pageSmartlookWizard'));
    }

    public function pageDashboard()
    {
        /* Description: Displays dashboard page */
        $pagename = $this->pp_prefix . 'menu' . ucfirst(__FUNCTION__);
        $include = substr(strtolower(__FUNCTION__), 4);
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_code.inc.php");

        //Output
        require(plugin_dir_path(__FILE__) . "pages/messages_output.inc.php");
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_output.inc.php");
    }

    public function pageConfiguration()
    {
        /* Description: Displays config page */
        $pagename = $this->pp_prefix . 'menu' . ucfirst(__FUNCTION__);
        $include = substr(strtolower(__FUNCTION__), 4);
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_code.inc.php");

        //Output
        require(plugin_dir_path(__FILE__) . "pages/messages_output.inc.php");
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_output.inc.php");
    }

    public function pageGoogleAnalyticsWizard()
    {
        /* Description: Displays the Google Analytics configuration wizard */
        $pagename = $this->pp_prefix . 'menu' . ucfirst(__FUNCTION__);
        $include = substr(strtolower(__FUNCTION__), 4);
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_code.inc.php");

        //Output
        require(plugin_dir_path(__FILE__) . "pages/messages_output.inc.php");
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_output.inc.php");
    }

    public function pageFacebookPixelWizard()
    {
        /* Description: Displays the Facebook Pixel wizard */
        $pagename = $this->pp_prefix . 'menu' . ucfirst(__FUNCTION__);
        $include = substr(strtolower(__FUNCTION__), 4);
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_code.inc.php");

        //Output
        require(plugin_dir_path(__FILE__) . "pages/messages_output.inc.php");
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_output.inc.php");
    }

    public function pageSmartlookWizard()
    {
        /* Description: Displays the smartlook wizard */
        $pagename = $this->pp_prefix . 'menu' . ucfirst(__FUNCTION__);
        $include = substr(strtolower(__FUNCTION__), 4);
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_code.inc.php");

        //Output
        require(plugin_dir_path(__FILE__) . "pages/messages_output.inc.php");
        require(plugin_dir_path(__FILE__) . "pages/" . $include . "_output.inc.php");
    }

    //Plugin functions
    public function echoGoogleAnalyticsTracking()
    {
        /* Description: Output the Google Analytics code if possible */

        if (!isset($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'])
            OR ($this->pp_config['google_analytics_respect_wp_consent_manager_pro_settings'] == 'N')
            OR (($this->pp_config['google_analytics_respect_wp_consent_manager_pro_settings'] == 'Y')
                AND isset($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'])
                AND method_exists($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'], 'getEvaluatedUserConsentType')
                AND ($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT']->getEvaluatedUserConsentType('PERFORMANCE_COOKIES') == 'Y'))) {

            // This is the integration with WP Consent Manager PRO, which means we only show the tracking code when
            // - WP Consent Manager PRO is not installed
            // - WP Consent Manager PRO is/is not installed but should not be evaluated anyway
            // - WP Consent Manager PRO is installed, should be evaluated, and the user has a consent given (or by config default)
            // We evaluate this here and not in the add_hooks section, as we are sure here, that the plugins are all loaded!

            if (strlen($this->pp_config['google_analytics_key']) > 0) {
                echo '<script type="text/javascript">' . PHP_EOL;
                echo ' /* Google Analytics tracking by ' . $this->pp_plugin_name_read . ' (https://www.wpserviceagent.com/plugins/wp-lean-analytics) */' . PHP_EOL;
                echo "(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
})(window,document,'script','https://www.google-analytics.com/analytics.js','ga');" . PHP_EOL;

                echo "ga('create', '" . $this->pp_config['google_analytics_key'] . "', 'auto');" . PHP_EOL;
                echo "ga('set', 'forceSSL', true);" . PHP_EOL;
                if ($this->pp_config['google_analytics_anonymize_ip'] == 'Y') {
                    echo "ga('set', 'anonymizeIp', true);" . PHP_EOL;
                }
                echo "ga('send', 'pageview');" . PHP_EOL;

                echo '</script>' . PHP_EOL;
            }
        }
    }

    public function echoFacebookPixelTracking()
    {
        /* Description: Output the Facebook Pixel code if possible */

        if (!isset($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'])
            OR ($this->pp_config['facebook_analytics_respect_wp_consent_manager_pro_settings'] == 'N')
            OR (($this->pp_config['facebook_analytics_respect_wp_consent_manager_pro_settings'] == 'Y')
                AND isset($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'])
                AND method_exists($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'], 'getEvaluatedUserConsentType')
                AND ($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT']->getEvaluatedUserConsentType('PERFORMANCE_COOKIES') == 'Y'))) {

            // This is the integration with WP Consent Manager PRO, which means we only show the tracking code when
            // - WP Consent Manager PRO is not installed
            // - WP Consent Manager PRO is/is not installed but should not be evaluated anyway
            // - WP Consent Manager PRO is installed, should be evaluated, and the user has a consent given (or by config default)
            // We evaluate this here and not in the add_hooks section, as we are sure here, that the plugins are all loaded!

            if (strlen($this->pp_config['facebook_analytics_key']) > 0) {
                echo '<script type="text/javascript">' . PHP_EOL;
                echo ' /* Facebook tracking by ' . $this->pp_plugin_name_read . ' (https://www.wpserviceagent.com/plugins/wp-lean-analytics)  */' . PHP_EOL;

                echo "!function(f,b,e,v,n,t,s)
    {if(f.fbq)return;n=f.fbq=function(){n.callMethod?
    n.callMethod.apply(n,arguments):n.queue.push(arguments)};
    if(!f._fbq)f._fbq=n;n.push=n;n.loaded=!0;n.version='2.0';
    n.queue=[];t=b.createElement(e);t.async=!0;
    t.src=v;s=b.getElementsByTagName(e)[0];
    s.parentNode.insertBefore(t,s)}(window,document,'script',
    'https://connect.facebook.net/en_US/fbevents.js');" . PHP_EOL;

                echo "fbq('init', '" . $this->pp_config['facebook_analytics_key'] . "');" . PHP_EOL;
                echo "fbq('track', 'PageView');" . PHP_EOL;
                echo '</script>' . PHP_EOL;
            }
        }
    }

    public function echoSmartlookTracking()
    {
        /* Description: Output the Smartlook code if possible (and depending on settings) */

        if (!isset($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'])
            OR ($this->pp_config['smartlook_analytics_respect_wp_consent_manager_pro_settings'] == 'N')
            OR (($this->pp_config['smartlook_analytics_respect_wp_consent_manager_pro_settings'] == 'Y')
                AND isset($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'])
                AND method_exists($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT'], 'getEvaluatedUserConsentType')
                AND ($GLOBALS['WP_CONSENT_MANAGER_PRO_OBJECT']->getEvaluatedUserConsentType('PERFORMANCE_COOKIES') == 'Y'))) {

            // This is the integration with WP Consent Manager PRO, which means we only show the tracking code when
            // - WP Consent Manager PRO is not installed
            // - WP Consent Manager PRO is/is not installed but should not be evaluated anyway
            // - WP Consent Manager PRO is installed, should be evaluated, and the user has a consent given (or by config default)
            // We evaluate this here and not in the add_hooks section, as we are sure here, that the plugins are all loaded!

            if (strlen($this->pp_config['smartlook_analytics_key']) > 0) {
                //Smartlook tracking is enabled
                echo '<script type="text/javascript">' . PHP_EOL;
                echo '/* Smartlook tracking by ' . $this->pp_plugin_name_read . ' (https://www.wpserviceagent.com/plugins/wp-lean-analytics)  */' . PHP_EOL;

                echo "window.smartlook||(function(d) {
        var o=smartlook=function(){ o.api.push(arguments)},h=d.getElementsByTagName('head')[0];
        var c=d.createElement('script');o.api=new Array();c.async=true;c.type='text/javascript';
        c.charset='utf-8';c.src='https://rec.smartlook.com/recorder.js';h.appendChild(c);
        })(document);" . PHP_EOL;

                echo "smartlook('init', '" . $this->pp_config['smartlook_analytics_key'] . "');" . PHP_EOL;
                echo '</script>' . PHP_EOL;
            }
        }
    }

    //Admin POST action wrappers
    public function do_updateOptions()
    {
        /* Description: Wrapper for do_updateOptions */

        $error_status = false;
        $something_changed = false;

        if (isset($_REQUEST[$this->pp_prefix . 'redirect_page'])) {
            $redirect_page = $_REQUEST[$this->pp_prefix . 'redirect_page'];
        } else {
            $redirect_page = $this->pp_prefix . 'menuPages';
        }

        $url = admin_url('admin.php?page=' . $redirect_page);

        if (wp_verify_nonce($_REQUEST['_wpnonce'], $this->pp_prefix . 'updateOptions') != false) {

            $option_update = $this->updateConfigAttributes($this->pp_config, $_REQUEST[$this->pp_prefix . 'data']['option_new']);

            if (isset($option_update)
                AND ($option_update != false)
                AND is_array($option_update)
                AND (count($option_update) > 0)) {
                foreach ($option_update AS $key => $value) {
                    if ($value == 'SAME') {
                        unset($option_update[$key]);
                    } elseif ($value == 'CHANGEABLE') {
                        $something_changed = true;
                    } else {
                        $error_status = true;
                    }
                }
            }

            if (isset($_REQUEST[$this->pp_prefix . 'next_step'])
                AND (strlen($_REQUEST[$this->pp_prefix . 'next_step']) > 0)
                AND is_numeric($_REQUEST[$this->pp_prefix . 'next_step'])
                AND ($_REQUEST[$this->pp_prefix . 'next_step'] > 0)) {
                //Add step to url
                if ($error_status == true) {
                    if (isset($_REQUEST[$this->pp_prefix . 'current_step'])
                        AND (strlen($_REQUEST[$this->pp_prefix . 'current_step']) > 0)
                        AND is_numeric($_REQUEST[$this->pp_prefix . 'current_step'])
                        AND ($_REQUEST[$this->pp_prefix . 'current_step'] > 0)) {
                        //Current step was given, take that
                        $step = $_REQUEST[$this->pp_prefix . 'current_step'];
                    } else {
                        //No current step given, take next_step - 1
                        $step = $_REQUEST[$this->pp_prefix . 'next_step'] - 1;
                    }
                } else {
                    //All is well, take next step
                    $step = $_REQUEST[$this->pp_prefix . 'next_step'];
                }

                $url = add_query_arg(array($this->pp_prefix . 'step' => $step), $url);
            }

            if (isset($option_update)
                AND ($option_update != false)
                AND is_array($option_update)
                AND (count($option_update) > 0)) {
                //Add option update status to URL
                $url = add_query_arg(array($this->pp_prefix . 'option_update' => $option_update), $url);
            }

        } else {
            //Nonce not valid
            $error_status = true;
        }

        if (($error_status == false)
            AND ($something_changed == true)) {
            //Redirect to positive admin message
            $url = add_query_arg(array($this->pp_prefix . 'updateOptions_status' => 'success'), $url);
        } elseif ($error_status == true) {
            //Redirect to negative admin message
            $url = add_query_arg(array($this->pp_prefix . 'updateOptions_status' => 'error'), $url);
        }

        wp_redirect($url);

        exit();
    }
}

?>